"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FrameType;
(function (FrameType) {
    FrameType[FrameType["Data"] = 0] = "Data";
    FrameType[FrameType["Size"] = 1] = "Size";
    FrameType[FrameType["Name"] = 2] = "Name";
    FrameType[FrameType["Cwd"] = 3] = "Cwd";
})(FrameType = exports.FrameType || (exports.FrameType = {}));
function decode(buf) {
    if (buf.length < 4) {
        return null;
    }
    const size = buf.readUInt32BE(0);
    if (buf.length < size + 4) {
        return null;
    }
    const type = buf.readUInt8(4);
    switch (type) {
        case FrameType.Data:
            return {
                type: FrameType.Data,
                size: size + 4,
                data: buf.slice(5, 5 + size - 1)
            };
        case FrameType.Size:
            return {
                type: FrameType.Size,
                size: size + 4,
                cols: buf.readUInt16BE(5),
                rows: buf.readUInt16BE(7)
            };
        case FrameType.Name:
            return {
                type: FrameType.Name,
                size: size + 4,
                name: buf.slice(5, 5 + size - 1).toString('utf8')
            };
        case FrameType.Cwd:
            return {
                type: FrameType.Cwd,
                size: size + 4,
                cwd: buf.slice(5, 5 + size - 1).toString('utf8')
            };
        default:
            throw new Error(`Unknown frame type: ${type}`);
    }
}
exports.decode = decode;
function encodeData(data) {
    const dataBuf = Buffer.from(data, 'utf8');
    const buf = Buffer.alloc(5 + dataBuf.length);
    buf.writeUInt32BE(dataBuf.length + 1, 0);
    buf.writeUInt8(FrameType.Data, 4);
    dataBuf.copy(buf, 5);
    return buf;
}
exports.encodeData = encodeData;
function encodeSize(cols, rows) {
    const buf = Buffer.alloc(9);
    buf.writeUInt32BE(5, 0);
    buf.writeUInt8(FrameType.Size, 4);
    buf.writeUInt16BE(cols, 5);
    buf.writeUInt16BE(rows, 7);
    return buf;
}
exports.encodeSize = encodeSize;
//# sourceMappingURL=frame.js.map